Adds boolean flags to identify state, district, and school level records. In GOSA data, there's no explicit state row, so we need to identify levels by the presence/absence of district and school IDs.
Examples
if (FALSE) { # \dontrun{
tidy_data <- fetch_assessment(2024)
# Data already has aggregation flags via id_assessment_aggs
table(tidy_data$is_school)
} # }